@@ -1,11 +1,10 @@
 #  !/usr/bin/env python
-#   -*- coding: utf-8 -*-
 #
 #  sizes.py
 """
 Common pagesizes in point/pt
 
-TODO: list of the page sizes
+.. TODO:: list of the page sizes
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -36,6 +35,114 @@ TODO: list of the page sizes
 #  MA 02110-1301, USA.
 #
 
+__all__ = [
+		"_4A0",
+		"_2A0",
+		"A0",
+		"A1",
+		"A2",
+		"A3",
+		"A4",
+		"A5",
+		"A6",
+		"A7",
+		"A8",
+		"A9",
+		"A10",
+		"B0",
+		"B1",
+		"B2",
+		"B3",
+		"B4",
+		"B5",
+		"B6",
+		"B7",
+		"B8",
+		"B9",
+		"B10",
+		"C0",
+		"C1",
+		"C2",
+		"C3",
+		"C4",
+		"C5",
+		"C6",
+		"C7",
+		"C8",
+		"C9",
+		"C10",
+		"A2EXTRA",
+		"A3EXTRA",
+		"A3SUPER",
+		"SUPERA3",
+		"A4EXTRA",
+		"A4SUPER",
+		"SUPERA4",
+		"A4LONG",
+		"A5EXTRA",
+		"SOB5EXTRA",
+		"LETTER",
+		"LEGAL",
+		"TABLOID",
+		"ELEVENSEVENTEEN",
+		"JUNIOR_LEGAL",
+		"HALF_LETTER",
+		"GOV_LETTER",
+		"GOV_LEGAL",
+		"LEDGER",
+		"EMPEROR",
+		"QUAD_ROYAL",
+		"QUAD_DEMY",
+		"ANTIQUARIAN",
+		"GRAND_EAGLE",
+		"DOUBLE_ELEPHANT",
+		"ATLAS",
+		"DOUBLE_ROYAL",
+		"COLOMBIER",
+		"DOUBLE_DEMY_US",
+		"DOUBLE_DEMY",
+		"DOUBLE_DEMY_UK",
+		"IMPERIAL",
+		"DOUBLE_LARGE_POST",
+		"ELEPHANT",
+		"PRINCESS",
+		"CARTRIDGE",
+		"ROYAL",
+		"SHEET",
+		"HALF_POST",
+		"DOUBLE_POST",
+		"SUPER_ROYAL",
+		"BROADSHEET",
+		"MEDIUM_US",
+		"MEDIUM_UK",
+		"DEMY",
+		"COPY_DRAUGHT",
+		"LARGE_POST_US",
+		"LARGE_POST_UK",
+		"POST_US",
+		"POST_UK",
+		"CROWN",
+		"PINCHED_POST",
+		"FOOLSCAP_US",
+		"FOOLSCAP_UK",
+		"SMALL_FOOLSCAP",
+		"BRIEF",
+		"POTT",
+		"QUARTO_US",
+		"EXECUTIVE",
+		"MONARCH",
+		"FOLIO",
+		"FOOLSCAP_FOLIO",
+		"QUARTO",
+		"QUARTO_UK",
+		"KINGS",
+		"DUKES",
+		"ID_1",
+		"ID_2",
+		"ID_3",
+		"ID_000",
+		]
+
 # this package
 from .classes import Size_inch, Size_mm
 
