@@ -1,9 +1,8 @@
 #  !/usr/bin/env python
-#   -*- coding: utf-8 -*-
 #
 #  utils.py
 """
-Tools for working with pagesizes
+Tools for working with pagesizes.
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -36,30 +35,38 @@ Tools for working with pagesizes
 
 # stdlib
 import re
-from decimal import Decimal
-from typing import Sequence, Tuple, Union
+from typing import Sequence, Tuple, Union, overload
 
 # this package
 from ._types import AnyNumber
-from .units import cc, cm, dd, inch, mm, nc, nd, pc, pica, sp, um
+from .units import Unit, cm, inch, mm, pc, pt, um
 
 # from .units import Unit
 
 __all__ = ["convert_from", "parse_measurement"]
 
 
+@overload
+def convert_from(value: Sequence[AnyNumber], from_: AnyNumber) -> Tuple[float, ...]:
+	...  # pragma: no cover
+
+
+@overload
+def convert_from(value: AnyNumber, from_: AnyNumber) -> float:
+	...  # pragma: no cover
+
+
 def convert_from(
 		value: Union[Sequence[AnyNumber], AnyNumber],
 		from_: AnyNumber,
 		) -> Union[float, Tuple[float, ...]]:
 	"""
-	Convert ``value`` to point from the unit specified in ``from_``
+	Convert ``value`` to point from the unit specified in ``from_``.
 
 	:param value:
 	:param from_: The unit to convert from, specified as a number of points
 
 	:return:
-	:rtype:
 	"""
 
 	if isinstance(value, Sequence):
@@ -69,76 +76,53 @@ def convert_from(
 
 
 def _sequence_convert_from(seq: Sequence[AnyNumber], from_: AnyNumber) -> Tuple[float, ...]:
-	from_ = float(from_)
+	if isinstance(from_, Unit):
+		from_ = from_._in_pt
+	else:
+		from_ = float(from_)
 
 	return tuple(float(x) * from_ for x in seq)
 
 
-_measurement_re = re.compile(r"(\d*\.?\d+) *([A-Za-z]*)")
+_measurement_re = re.compile(r"(\d*\.?\d+) *([A-Za-zμµ\"']*)")
 
 
-def parse_measurement(measurement):
-	# TODO: docstring
-	match = _measurement_re.findall(measurement)[0]
-	print(match)
-	print(len(match))
-	if len(match) < 2:
-		raise ValueError("Unable to parse measurement")
-	else:
-		val = Decimal(str(match[0]))
-		unit = match[1]
-		if unit == "mm":
-			return convert_from(val, mm)
-		elif unit == "cm":
-			return convert_from(val, cm)
-		elif unit in {"um", "μm", "µm"}:
-			return convert_from(val, um)
-		elif unit == "pt":
-			return val
-		elif unit == "inch":
-			return convert_from(val, inch)
-		elif unit == "in":
-			return convert_from(val, inch)
-		elif unit == "pc":
-			return convert_from(val, pc)
-		elif unit == "dd":
-			return convert_from(val, dd)
-		elif unit == "cc":
-			return convert_from(val, cc)
-		elif unit == "nd":
-			return convert_from(val, nd)
-		elif unit == "nc":
-			return convert_from(val, nc)
-		elif unit == "sp":
-			return convert_from(val, sp)
-		raise ValueError("Unknown unit")
-
-
-def to_length(s):
+def parse_measurement(measurement: str) -> Union[float, Tuple[float, ...]]:
 	"""
-	Convert a string to a length
+	Parse the given measurement.
+
+	:param measurement:
+	:type measurement: str
 
-	:param s:
-	:type s:
 	:return:
-	:rtype:
-
-	# TODO: combine with parse_measurement
 	"""
 
-	try:
-		if s[-2:] == 'cm':
-			return float(s[:-2]) * cm
-		if s[-2:] == 'in':
-			return float(s[:-2]) * inch
-		if s[-2:] == 'pt':
-			return float(s[:-2])
-		if s[-1:] == 'i':
-			return float(s[:-1]) * inch
-		if s[-2:] == 'mm':
-			return float(s[:-2]) * mm
-		if s[-4:] == 'pica':
-			return float(s[:-4]) * pica
-		return float(s)
-	except:
-		raise ValueError(f"Can't convert_to '{s}' to length")
+	# TODO: docstring
+	all_matches = _measurement_re.findall(measurement)
+
+	if len(all_matches) > 1:
+		raise ValueError("Too many measurements")
+	elif len(all_matches) == 0:
+		raise ValueError("Unable to parse measurement")
+
+	val, unit = all_matches[0]
+
+	if "" in {val, unit}:
+		raise ValueError("Unable to parse measurement")
+
+	val = float(val)
+
+	if unit == "mm":
+		return val * mm
+	elif unit == "cm":
+		return val * cm
+	elif unit in {"um", "μm", "µm"}:  # second is mu, third is micro
+		return val * um
+	elif unit == "pt":
+		return val * pt
+	elif unit in {"inch", "in", '"'}:
+		return val * inch
+	elif unit in ("pc", "pica"):
+		return val * pc
+
+	raise ValueError("Unknown unit")
