@@ -7,24 +7,16 @@ Functions for paths and files.
 #
 #  Copyright © 2018-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
-#  check_dependencies based on https://stackoverflow.com/a/29044693/3092681
-#  		Copyright © 2015 TehTechGuy
-# 		Licensed under CC-BY-SA
-#
-#  as_text from https://stackoverflow.com/a/40935194
-# 		Copyright © 2016 User3759685
-# 		Available under the MIT License
-#
-#  chunks from https://stackoverflow.com/a/312464/3092681
-# 		Copytight © 2008 Ned Batchelder
-# 		Licensed under CC-BY-SA
-#
 #  Parts of the docstrings and the PathPlus class based on the Python 3.8.2 Documentation
 #  Licensed under the Python Software Foundation License Version 2.
 #  Copyright © 2001-2020 Python Software Foundation. All rights reserved.
 #  Copyright © 2000 BeOpen.com . All rights reserved.
-#  Copyright © 1995-2000 Corporation for National Research Initiatives . All rights reserved.
-#  Copyright © 1991-1995 Stichting Mathematisch Centrum . All rights reserved.
+#  Copyright © 1995-2000 Corporation for National Research Initiatives. All rights reserved.
+#  Copyright © 1991-1995 Stichting Mathematisch Centrum. All rights reserved.
+#
+#  copytree based on https://stackoverflow.com/a/12514470/3092681
+#      Copyright © 2012 atzz
+#      Licensed under CC-BY-SA
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU Lesser General Public License as published by
@@ -57,10 +49,6 @@ def append(var: str, filename: PathLike, **kwargs) -> int:
 	"""
 	Append ``var`` to the file ``filename`` in the current directory.
 
-	.. warning::
-
-		This is currently untested
-
 	.. TODO:: make this the file in the given directory, by default the current directory
 
 	:param var: The value to append to the file
@@ -76,9 +64,14 @@ def copytree(
 		dst: PathLike,
 		symlinks: bool = False,
 		ignore: Optional[Callable] = None,
-		):
+		) -> PathLike:
 	"""
-	Alternative to :func:`shutil.copytree` to work in some situations where it doesn't.
+	Alternative to :func:`shutil.copytree` to support copying to a directory that already exists.
+
+	Based on https://stackoverflow.com/a/12514470/3092681 by https://stackoverflow.com/users/23252/atzz
+
+	In Python 3.8 and above :func:`shutil.copytree` takes a ``dirs_exist_ok`` argument,
+	which has the same result.
 
 	:param src: Source file to copy
 	:param dst: Destination to copy file to
@@ -106,19 +99,17 @@ def copytree(
 		s = os.path.join(src, item)
 		d = os.path.join(dst, item)
 		if os.path.isdir(s):
-			return shutil.copytree(s, d, symlinks, ignore)
+			shutil.copytree(s, d, symlinks, ignore)
 		else:
-			return shutil.copy2(s, d)
+			shutil.copy2(s, d)
+
+	return dst
 
 
 def delete(filename: PathLike, **kwargs):
 	"""
 	Delete the file in the current directory.
 
-	.. warning::
-
-		This is currently untested
-
 	.. TODO:: make this the file in the given directory, by default the current directory
 
 	:param filename: The file to delete
@@ -131,6 +122,11 @@ def maybe_make(directory: PathLike, mode: int = 0o777, parents: bool = False, ex
 	"""
 	Create a directory at the given path, but only if the directory does not already exist.
 
+	.. note::
+
+		This will fail silently if a file with the same name already exists.
+		This appears to be due to the behaviour of :func:`os.mkdir`.
+
 	:param directory: Directory to create
 	:param mode: Combined with the process’ umask value to determine the file mode and access flags
 	:type mode:
@@ -173,10 +169,6 @@ def read(filename: PathLike, **kwargs) -> str:
 	"""
 	Read a file in the current directory (in text mode).
 
-	.. warning::
-
-		This is currently untested
-
 	.. TODO:: make this the file in the given directory, by default the current directory
 
 	:param filename: The file to read from
@@ -290,7 +282,7 @@ class PathPlus(pathlib.Path):
 	def __new__(cls, *args, **kwargs):
 		if cls is PathPlus:
 			cls = WindowsPathPlus if os.name == 'nt' else PosixPathPlus
-		self = cls._from_parts(args, init=False)
+		self = cls._from_parts(args, init=False)  # type: ignore
 		if not self._flavour.is_supported:
 			raise NotImplementedError(f"cannot instantiate {cls.__name__!r} on your system")
 		self._init()
@@ -333,6 +325,11 @@ class PathPlus(pathlib.Path):
 		"""
 		Create a directory at this path, but only if the directory does not already exist.
 
+		.. note::
+
+			This will fail silently if a file with the same name already exists.
+			This appears to be due to the behaviour of :func:`os.mkdir`.
+
 		:param mode: Combined with the process’ umask value to determine the file mode and access flags
 		:type mode:
 		:param parents: If :py:obj:`False` (the default), a missing parent raises a :class:`~python:FileNotFoundError`.
